@@ -31,6 +31,7 @@
 
 // Internal classes
 class ODi_FontFaceDecls;
+class ODi_Abi_Data;
 
 // AbiWord classes
 class PD_Document;
@@ -51,7 +52,9 @@ public:
     };
 
 
-    ODi_Style_Style(ODi_ElementStack& rElementStack);
+    ODi_Style_Style(ODi_ElementStack& rElementStack,
+		    ODi_Abi_Data & rAbiData);
+
     virtual ~ODi_Style_Style() {}
 
     void startElement(const gchar* pName, const gchar** ppAtts,
@@ -76,7 +79,8 @@ public:
      * @param pDocument The AbiWord document on which the style will be defined.
      */
     void defineAbiStyle(PD_Document* pDocument);
-    
+    ODi_Abi_Data & getAbiData(void)
+      { return m_rAbiData;} 
     
     /**
      * Builds the AbiWord "props" attribute value that describes this
@@ -125,8 +129,11 @@ public:
     inline void setNextStyleName(const char* pName) {m_nextStyleName.assign(pName);}
     void setNextStyleName(const UT_UTF8String& rName) {m_nextStyleName = rName;}
  
+	const UT_UTF8String& getListStyleName() const {return m_listStyleName;}
+
     bool hasProperties() const {
-        return !m_masterPageName.empty() ||
+        return !m_listStyleName.empty() ||
+               !m_masterPageName.empty() ||
         
                !m_lineHeight.empty() ||
                !m_align.empty() ||
@@ -164,18 +171,22 @@ public:
 	       !m_VerticalRel.empty() ||
              
                !m_backgroundColor.empty() ||
+               !m_backgroundImageID.empty() ||
     
                !m_columnWidth.empty() ||
+               !m_columnRelWidth.empty() ||
                
                !m_minRowHeight.empty() ||
                !m_TableMarginLeft.empty() ||
                !m_TableMarginRight.empty() ||
                !m_TableWidth.empty() ||
+               !m_TableRelWidth.empty() ||
                !m_rowHeight.empty();
     }
     
     bool isAutomatic() const {return m_bAutomatic;}
     const UT_UTF8String* getMarginLeft() const {return &m_marginLeft;}
+    const UT_UTF8String* getTextIndent() const {return &m_textIndent;}
     const UT_UTF8String* getFamily() const {return &m_family;}
     const UT_UTF8String* getFontName() const {return &m_fontName;}
     
@@ -189,8 +200,10 @@ public:
     const UT_UTF8String* getVerticalPos(bool local) const;
     
     const UT_UTF8String* getBackgroundColor() const;
+    const UT_UTF8String* getBackgroundImageID() const;
     
     const UT_UTF8String* getColumnWidth() const {return &m_columnWidth;}
+    const UT_UTF8String* getColumnRelWidth() const {return &m_columnRelWidth;}
     
     const UT_UTF8String* getMinRowHeight() const {return &m_minRowHeight;}
     const UT_UTF8String* getRowHeight() const {return &m_rowHeight;}
@@ -217,6 +230,7 @@ public:
     const UT_UTF8String* getTableMarginLeft() const {return &m_TableMarginLeft;}
     const UT_UTF8String* getTableMarginRight() const {return &m_TableMarginRight;}
     const UT_UTF8String* getTableWidth() const {return &m_TableWidth;}
+    const UT_UTF8String* getTableRelWidth() const {return &m_TableRelWidth;}
 private:
 
     // <style:style />
@@ -245,6 +259,9 @@ private:
     
     // <style:table-cell-properties />
     void _parse_style_tableCellProperties(const gchar** ppProps);
+
+    // <style:background-image />
+    void _parse_style_background_image(const gchar** ppProps);
     
     /**
      * If pString is "0.0556in solid #0000ff", rColor will receive "#0000ff",
@@ -364,14 +381,19 @@ private:
     // For <style:table-properties> and <style:table-cell-properties>
     UT_UTF8String m_backgroundColor;
 
+    // <style:bakground-image>
+    UT_UTF8String m_backgroundImageID; // xlink:href
+
     // For <style:table-properties 
     // fo:margin-left
     // fo:margin-right
     // style:width
+    // style:rel-width
     
     UT_UTF8String   m_TableMarginLeft;
     UT_UTF8String   m_TableMarginRight;
     UT_UTF8String   m_TableWidth;
+    UT_UTF8String   m_TableRelWidth;
 
     
     ////
@@ -390,7 +412,10 @@ private:
 
     ////
     // <style:table-column-properties>
+    // style:column-width
+    // rel-column-width
     UT_UTF8String m_columnWidth; // style:column-width
+    UT_UTF8String m_columnRelWidth; // style:rel-column-width
     
     ////
     // <style:table-row-properties>
@@ -420,7 +445,9 @@ private:
     UT_UTF8String m_borderRight_thickness;
     UT_UTF8String m_borderRight_color;
     HAVE_BORDER m_haveRightBorder;
-    
+
+    ODi_Abi_Data& m_rAbiData;
+   
     // OBS: If "fo:border" is defined, its value will fill all "fo:border-*"
 };
 
