@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiSource Program Utilities
  *
  * Copyright (C) 2001 Mike Nordell <tamlin@alogonet.se>
@@ -47,22 +49,13 @@
 // fwd. decl.
 template <class T> class hash_slot;
 
-template <class T> class ABI_EXPORT UT_GenericStringMap;
+template <class T> class UT_GenericStringMap;
 
-	// Like a std cursor
-
-class _UT_StringMapImp
-{
-
-
-};
-
-
-template <class T> class ABI_EXPORT UT_GenericStringMap
+template <class T> class UT_GenericStringMap
 {
 public:
 	UT_GenericStringMap(size_t expected_cardinality = 11);
-	~UT_GenericStringMap();
+	virtual ~UT_GenericStringMap();
 
 	// insertion/addition
 	bool insert(const char* key, T value);
@@ -91,8 +84,7 @@ public:
 	UT_GenericVector<T>* enumerate(bool strip_null_values = true) const;
 	UT_GenericVector<const UT_String*>* keys(bool strip_null_values = true) const;
 	
-	// these are synonyms - for getting the # keys
-	inline size_t cardinality() const { return n_keys; }
+	// getting the # keys
 	inline size_t size() const { return n_keys; }
 
 	class UT_Cursor
@@ -124,9 +116,9 @@ public:
 		
 	private:
 		
-		inline void	_set_index(int i)	
+		inline void	_set_index(UT_sint32 i)	
 			{ m_index = i; }
-		inline int	_get_index()		
+		inline UT_sint32 _get_index()		
 			{ return m_index; }
 		
 		const UT_GenericStringMap<T>*	m_d;
@@ -154,7 +146,7 @@ public:
 			for ( T hval1 = hc1.first(); hc1.is_valid(); hval1 = hc1.next() ) {
 				if (hval1) {
 					hc1.make_deleted();
-					g_free(const_cast<T>(hval1));
+					g_free((gpointer)(hval1));
 				}
 			}
 		}
@@ -244,18 +236,24 @@ template class ABI_EXPORT UT_GenericStringMap<char *>;
 
 //template class ABI_EXPORT UT_GenericStringMap<void const*>;
 #endif
-typedef UT_GenericStringMap<void const *>  UT_StringPtrMap;
-
 
+// TODO Rob: try to export like this once plugin loading is fixed:
+// template class ABI_EXPORT UT_GenericStringMap<void const *>;
+class ABI_EXPORT UT_StringPtrMap : public UT_GenericStringMap<void const *> {
+public:
+	UT_StringPtrMap(size_t expected_cardinality = 11)
+	: UT_GenericStringMap<void const *>(expected_cardinality)
+	{}
+};
 
 // Template implementation
 
 // fwd. decls.
-UT_uint32 _Recommended_hash_size(UT_uint32	size);
+ABI_EXPORT UT_uint32 _Recommended_hash_size(UT_uint32	size);
 
 
 // wrapper class for keys
-class key_wrapper
+class ABI_EXPORT key_wrapper
 {
 public:
 	key_wrapper() 
@@ -358,6 +356,7 @@ public:
 	bool key_eq(const char  *test, size_t h) const
 		{
 #if 1
+			(void)h;
 			return m_key.eq(test);
 #else
 			return m_key.hashval() == h;
@@ -409,9 +408,9 @@ const gchar ** UT_GenericStringMap<T>::list()
 
 		UT_Cursor c(this);
 
-		for (const gchar * value = reinterpret_cast<gchar*>(c.first ()); 
+		for (const gchar * value = (gchar*)(c.first ()); 
 			 c.is_valid (); 
-			 value = reinterpret_cast<gchar*>(c.next ()))
+			 value = (gchar*)(c.next ()))
 		{
 			const char * key = c.key().c_str ();
 
@@ -722,7 +721,7 @@ UT_GenericStringMap<T>::find_slot(const char *k,
 							size_t&			hashval,
 							const void*		v,
 							bool*			v_found,
-							void*			vi,
+							void*			/*vi*/,
 							size_t			hashval_in) const
 {
 	if ( m_nSlots == 0 )
@@ -945,7 +944,7 @@ template <class T> const T
 UT_GenericStringMap<T>::_prev(UT_Cursor& c) const
 {
 	const hash_slot<T>* map = m_pMapping;
-	size_t x;
+	UT_sint32 x;
 	for (x = c._get_index() - 1; x >= 0; --x)
 	{
 		if (!map[x].empty() && !map[x].deleted())
